@@ -11,12 +11,12 @@ Eigen::ArrayXd LogitLink::computeMean(const Eigen::ArrayXd& linearPredictor) con
 
 Eigen::ArrayXd LogitLink::computeMeanDerivative(const Eigen::ArrayXd& linearPredictor) const
 {
-  return exp(linearPredictor) / pow(1 + exp(linearPredictor), 2);
+  return exp(linearPredictor) / pow(1. + exp(linearPredictor), 2);
 }
 
 Eigen::ArrayXd LogitLink::computeMeanSecondDerivative(const Eigen::ArrayXd& linearPredictor) const
 {
-  return exp(linearPredictor) * (1 - exp(linearPredictor)) / pow(1 + exp(linearPredictor), 3);
+  return exp(linearPredictor) * (1 - exp(linearPredictor)) / pow(1. + exp(linearPredictor), 3);
 }
 
 std::string LogitLink::getName() const
